Bug 11867 - need support for setup of wired-only Fab4
: need support for setup of wired-only Fab4
Status: RESOLVED FIXED
Product: SB Touch
Classification: Unclassified
Component: Setup
: unspecified
: PC Other
: -- critical (vote)
: MP
Assigned To: Richard Titmuss
:
Depends on:
Blocks:
  Show dependency treegraph
 
Reported: 2009-04-21 08:20 UTC by Ben Klaas
Modified: 2009-09-08 09:25 UTC (History)
3 users (show)

See Also:
Category: ---


Attachments

Note You need to log in before you can comment on or make changes to this bug.
Description Ben Klaas 2009-04-21 08:20:33 UTC
because of region support moving in front of wired vs. wireless selection, if we had a Fab4 without a wireless chip, it would fail on the region select screen and not be able to be setup.

this will probably be a trivial fix, but it's needed for MP. mine to fix today.

error in event function:
        ...ve/applets/SetupNetworking/SetupNetworkingApplet.lua:190: attempt to index local 'wlan' (a nil value)
stack traceback:
        ...ve/applets/SetupNetworking/SetupNetworkingApplet.lua:190: in function '_wirelessRegion'
        ...ve/applets/SetupNetworking/SetupNetworkingApplet.lua:105: in function <...ve/applets/SetupNetworking/SetupNetworkingApplet.lua:100>
        (tail call): ?
        ...are/jive/applets/SetupWelcome/SetupWelcomeApplet.lua:179: in function 'step3'
        ...are/jive/applets/SetupWelcome/SetupWelcomeApplet.lua:170: in function 'callback'
        /usr/share/jive/jive/ui/SimpleMenu.lua:169: in function 'itemListener'
        /usr/share/jive/jive/ui/Menu.lua:143: in function </usr/share/jive/jive/ui/Menu.lua:138>
        (tail call): ?
        /usr/share/jive/jive/ui/Menu.lua:770: in function 'callback'
        /usr/share/jive/jive/ui/Widget.lua:656: in function </usr/share/jive/jive/ui/Widget.lua:632>
        [C 0x237cc]: in function 'dispatchEvent'
        /usr/share/jive/jive/ui/Widget.lua:532: in function 'dispatchNewEvent'
        /usr/share/jive/jive/ui/Menu.lua:637: in function </usr/share/jive/jive/ui/Menu.lua:636>
        [C 0x52d9c]: in function 'pcall'
        /usr/share/jive/jive/ui/Timer.lua:187: in function '_runTimer'
        /usr/share/jive/jive/ui/Framework.lua:348: in function 'eventLoop'
        /usr/share/jive/jive/JiveMain.lua:344: in function </usr/share/jive/jive/JiveMain.lua:198>
        (tail call): ?
        /usr/share/jive/jive/JiveMain.lua:503: in main chunk
        [C 0x59a28]: ?
        [C 0x215c4]: ?
Comment 1 Ben Klaas 2009-04-21 08:26:28 UTC
fix appears to be dead simple. Richard, will you review?

=== SetupNetworkingApplet.lua
==================================================================
--- SetupNetworkingApplet.lua   (revision 31320)
+++ SetupNetworkingApplet.lua   (local)
@@ -179,8 +179,8 @@
 
 -- select wireless region
 function _wirelessRegion(self, wlan, transition)
-       -- skip region if already set and not in setup mode
-       if self:getSettings()['region'] and self.mode ~= "setup" then
+       -- skip region if already set and not in setup mode, or if no wlan is present
+       if ( self:getSettings()['region'] and self.mode ~= "setup" ) or not wlan then
                return _connectionType(self)
        end
Comment 2 Ben Klaas 2009-04-21 12:19:49 UTC
we've tested this enough to verify it works correctly. checked in as r5419

reopen as necessary